/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 1998-2018                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  Copyright (c) 2009-2015                                                **
**  German Research School for Simulation Sciences GmbH,                   **
**  Laboratory for Parallel Programming                                    **
**                                                                         **
**  Copyright (c) 2011                                                     **
**  University of Oregon, Eugene, USA                                      **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/



package scalasca.cubex.cube.datalayout.data.value;
import scalasca.cubex.cube.errors.*;
import scalasca.cubex.cube.services.transformation.*;
import java.lang.*;
import java.util.*;
import java.io.*;
/*
 * Class , delivers file structure of CubeX
 *
 */
public class CubeMinDouble extends CubeDouble
{
    public CubeMinDouble()
    {
        value = Double.MAX_VALUE;
    };

    public CubeMinDouble( double _v )
    {
        value = _v;
    };

    public String
    getName()
    {
        return "MINDOUBLE";
    }

    public Value
    clone()
    {
        return new CubeMinDouble();
    }
    public Value
    copy()
    {
        return new CubeMinDouble( value );
    }

    public Value
    clone( DataInputStream in )  throws IOException
    {
        return new CubeMinDouble( in.readDouble() );
    }

    // -------------------- lagebra -------------------------
    public void
    addValue( Value v )                // performs operation "+"
    {
        CubeMinDouble _v = ( CubeMinDouble )v;
        value = Math.min( value, _v.value );
    }

    public void
    subtractValue( Value v )                // performs operation "-", if defined
    {
        CubeMinDouble _v = ( CubeMinDouble )v;

        value = Math.max( value, _v.value );
    }
    public void
    setValueParameters( Vector<Double> parameters ) throws WrongNumberOfValueParametersException
    {
    };                                                                                                          // standard realization - nothing.
}
