/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 1998-2018                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  Copyright (c) 2009-2015                                                **
**  German Research School for Simulation Sciences GmbH,                   **
**  Laboratory for Parallel Programming                                    **
**                                                                         **
**  Copyright (c) 2011                                                     **
**  University of Oregon, Eugene, USA                                      **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/




package scalasca.cubex.cube.datalayout.data.value;
import scalasca.cubex.cube.errors.*;
import scalasca.cubex.cube.services.transformation.*;
import java.lang.*;
import java.lang.Number.*;
import java.util.*;
import java.io.*;
import java.math.*;

/*
 * Class , delivers file structure of CubeX
 *
 */
public class CubeUint64 extends Value
{
    protected BigInteger value;

    public CubeUint64()
    {
        value =  BigInteger.valueOf( 0 );
    };
    @SuppressWarnings( "unchecked" )
    public CubeUint64( long _v )
    {
        value = BigInteger.valueOf( _v );
    };

    public String
    getName()
    {
        return "UINT64";
    }



    public String
    toString()
    {
        return value.toString();
    }

    public int
    size()
    {
        return 8;
    };

    public void
    correctEndianess( Endianess _end, DataInputStream in, DataOutputStream out )  throws IOException
    {
        long _in  =  in.readLong();
        long __in = _end.applyOn( _in );
        out.writeLong( __in );
    }
    public Value
    clone()
    {
        return new CubeUint64();
    }
    public Value
    copy()
    {
        return new CubeUint64( value.longValue() );
    }

    public Value
    clone( DataInputStream in )  throws IOException
    {
        return new CubeUint64( in.readLong() );
    }
    // ------------------- setXXX methods ------------------
    public void
    setValue( String v )                // initialization from String
    {
        try
        {
            value = new BigInteger( v );
        }
        catch ( NumberFormatException e )
        {
            value = new BigInteger( new Long( ( long )( Double.valueOf( v ).doubleValue() ) ).toString() );
        }
    }
    public void
    setValue( byte v )                // initialization from byte
    {
        value = new BigInteger( Byte.toString( v ) );
    }

    public void
    setValue( short v )                // initialization from short
    {
        value = new BigInteger( Short.toString( v ) );
    }
    public void
    setValue( int v )                // initialization from integer
    {
        value = new BigInteger( Integer.toString( v ) );
    }
    public void
    setValue( long v )                // initialization from long
    {
        value = new BigInteger( Long.toString( v ) );
    }
    public void
    setValue( double v )                // initialization from double
    {
        value = new BigInteger( Double.toString( v ) );
    }

    // ------------------- getXXX methods ------------------
    public double
    getDouble()
    {
        return value.doubleValue();
    }

    // -------------------- lagebra -------------------------
    public void
    addValue( Value v )                // performs operation "+"
    {
        CubeUint64 _v = ( CubeUint64 )v;
        value = value.add( _v.value );
    }

    public void
    subtractValue( Value v )                // performs operation "-", if defined
    {
        CubeUint64 _v = ( CubeUint64 )v;
        value = value.subtract( _v.value );
    }
    public void
    setValueParameters( Vector<Double> parameters ) throws WrongNumberOfValueParametersException
    {
    };                                                                                                          // standard realization - nothing.
}
